<?php
/*
 * This file is part of FacetWP Carousel.
 *
 * FacetWP Carousel is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * FacetWP Carousel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with FacetWP Carousel.  If not, see <https://www.gnu.org/licenses/>.
 */

declare( strict_types=1 );

namespace FacetWPCarousel;

use FacetWPCarousel\Carousel\Block as CarouselBlock;
use FacetWPCarousel\Carousel\Rest as CarouselRest;
use FacetWPCarousel\Carousel\Shortcode as CarouselShortcode;
use Throwable;

class Bootstrap {
	public function __construct( string $plugin_file ) {
		self::setupTranslation( $plugin_file );
		self::loadClasses( $plugin_file );
	}

	private static function setupTranslation( string $plugin_file ): void {
		load_plugin_textdomain(
			'facetwp-carousel',
			false,
			dirname( plugin_basename( $plugin_file ) ) . '/languages'
		);
	}

	private static function loadClasses( string $plugin_file ): void {
		$classes = [
			CarouselBlock::class,
			CarouselShortcode::class,
			CarouselRest::class,
		];
		foreach ( $classes as $class ) {
			try {
				new $class( $plugin_file ); // phpcs:ignore NeutronStandard.Functions.VariableFunctions.VariableFunction
			} catch ( Throwable $err ) {
				$message = sprintf(
				// translators: %1$s is class name; %2$s is exception message.
					__(
						'<p>Could not load class "%1$s"</p><p><strong>Exception</strong>: %2$s</p>',
						'facetwp-carousel'
					),
					$class,
					$err->getMessage()
				);
				$title = __( 'Plugin initialization failed', 'facetwp-carousel' );
				wp_die( $message, $title );
			}
		}
	}
}
