<?php
/*
 * This file is part of FacetWP Carousel.
 *
 * FacetWP Carousel is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * FacetWP Carousel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with FacetWP Carousel.  If not, see <https://www.gnu.org/licenses/>.
 */

declare( strict_types=1 );

namespace FacetWPCarousel\Carousel;

use function register_block_type;
use function wp_set_script_translations;

class Block {
	private string $plugin_file;

	/**
	 * @param string $plugin_file
	 */
	public function __construct( string $plugin_file ) {
		$this->plugin_file = $plugin_file;
		add_action( 'init', [ $this, 'register_block' ] );
	}

	public function register_block() {
		/* @noinspection PhpIncludeInspection */
		$asset = include plugin_dir_path( $this->plugin_file ) . 'build/index.asset.php';

		wp_register_script(
			'facetwp-carousel-block',
			plugins_url( 'build/index.js', $this->plugin_file ),
			$asset['dependencies'],
			$asset['version'],
			true
		);

		wp_set_script_translations(
			'facetwp-carousel-block',
			'facetwp-carousel',
			plugin_dir_path( $this->plugin_file ) . 'languages'
		);

		register_block_type(
			'tandem/facetwp-carousel',
			[
				'editor_script' => 'facetwp-carousel-block',
			]
		);
	}

}
